#!/bin/bash

# Specify default min and max SM versions to check for
MINSMVER=${MINSMVER:-52}
MAXSMVER=${MAXSMVER:-86}

HAS_SUPPORTED_SMVER=0

DEVICE_STRING="Device[[:space:]][[:digit:]]*:[[:space:]]\"([[:print:]]*)\""
SM_VERSION_STRING="CUDA[[:space:]]Capability[[:space:]]Major/Minor[[:space:]]version number:[[:space:]]*([[:digit:]]*)\.([[:digit:]]*)"
# Detect SM versions present in the current system
while read i
do
  if [[ $i =~ $DEVICE_STRING ]]; then
    DEVICE_NAME=${BASH_REMATCH[1]}
  else
    if [[ $i =~ $SM_VERSION_STRING ]]; then
      DEVICE_SM_VER="${BASH_REMATCH[1]}${BASH_REMATCH[2]}"
      if [ $DEVICE_SM_VER -gt $MAXSMVER ]; then
        echo "WARNING: Detected NVIDIA $DEVICE_NAME GPU, which is not yet supported in this version of the container"
      fi
      if [ $DEVICE_SM_VER -ge $MINSMVER ]; then
        if [ $DEVICE_SM_VER -le $MAXSMVER ]; then
          ((HAS_SUPPORTED_SMVER++))
        fi
      else
        echo "ERROR: Detected NVIDIA $DEVICE_NAME GPU, which is not supported by this container"
      fi
    fi
  fi
done < <(`deviceQuery`)
if [ $HAS_SUPPORTED_SMVER -eq 0 ]; then
  echo "ERROR: No supported GPU(s) detected to run this container"
fi
